==> adx-common-2.6.6.7-sources.jar: com/bxm/adx/common/market/filter/CreativeFilter.java <==
package com.bxm.adx.common.market.filter;

import com.bxm.adx.common.buy.Buyer;
import com.bxm.adx.common.creative.CreativeService;
import com.bxm.adx.common.market.Deal;
import com.bxm.adx.common.sell.BidResponse;
import com.bxm.adx.common.sell.response.Bid;
import com.bxm.adx.common.sell.response.SeatBid;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;

import java.util.List;

/**
 * 创意过滤器
 *
 * @author allen
 * @since 2019-12-18
 */
@Order(Ordered.HIGHEST_PRECEDENCE)
@Slf4j
@Configuration
public class CreativeFilter implements Filter {

    private final CreativeService creativeService;

    public CreativeFilter(CreativeService creativeService) {
        this.creativeService = creativeService;
    }

    @Override
    public void filter(List<Deal> deals) {
        deals.removeIf(deal -> {
            BidResponse response = deal.getBidResponse();
            if (null == response) {
                if (log.isDebugEnabled()) {
                    log.debug("response is null");
                }
                return true;
            }
            Buyer buyer = deal.getBuyer();

            Long dspId = buyer.getDsp().getId();
            List<SeatBid> seatBidList = response.getSeat_bid();
            if (CollectionUtils.isEmpty(seatBidList)) {
                if (log.isDebugEnabled()) {
                    log.debug("response seatbids is null");
                }
                // 没有出价
                return true;
            }

            seatBidList.removeIf(seatBid -> {
                List<Bid> bids = seatBid.getBid();
                if (CollectionUtils.isEmpty(bids)) {
                    if (log.isDebugEnabled()) {
                        log.debug("response bids is null");
                    }
                    return true;
                }
                bids.removeIf(bid -> {
                    String tag_id = bid.getTag_id();
                    return !creativeService.isEnabled(tag_id, dspId, bid.getCreate_id());
                });
                return CollectionUtils.isEmpty(bids);
            });
            return CollectionUtils.isEmpty(seatBidList);
        });
    }

    @Override
    public int getOrder() {
        return Ordered.LOWEST_PRECEDENCE - 1;
    }
}

==> adx-common-2.7.9.24-sources.jar: com/bxm/adx/common/market/filter/CreativeFilter.java <==
package com.bxm.adx.common.market.filter;

import com.bxm.adx.common.buy.Buyer;
import com.bxm.adx.common.creative.CreativeService;
import com.bxm.adx.common.market.Deal;
import com.bxm.adx.common.sell.BidResponse;
import com.bxm.adx.common.sell.response.Bid;
import com.bxm.adx.common.sell.response.SeatBid;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;

import java.util.List;
import java.util.Set;

/**
 * 创意过滤器
 *
 * @author allen
 * @since 2019-12-18
 */
@Slf4j
//@Configuration
public class CreativeFilter implements Filter {

    private final CreativeService creativeService;

    public CreativeFilter(CreativeService creativeService) {
        this.creativeService = creativeService;
    }

    @Override
    public void filter(List<Deal> deals, Set<Deal> trash) {
        deals.removeIf(deal -> {
            BidResponse response = deal.getBidResponse();
            if (null == response) {
                if (log.isDebugEnabled()) {
                    log.debug("response is null");
                }
                return true;
            }
            Buyer buyer = deal.getBuyer();

            Long dspId = buyer.getDsp().getId();
            List<SeatBid> seatBidList = response.getSeat_bid();
            if (CollectionUtils.isEmpty(seatBidList)) {
                if (log.isDebugEnabled()) {
                    log.debug("response seatbids is null");
                }
                // 没有出价
                return true;
            }

            seatBidList.removeIf(seatBid -> {
                List<Bid> bids = seatBid.getBid();
                if (CollectionUtils.isEmpty(bids)) {
                    if (log.isDebugEnabled()) {
                        log.debug("response bids is null");
                    }
                    return true;
                }
                bids.removeIf(bid -> {
                    String tag_id = bid.getTag_id();
                    return !creativeService.isEnabled(tag_id, dspId, bid.getCreate_id());
                });
                return CollectionUtils.isEmpty(bids);
            });
            return CollectionUtils.isEmpty(seatBidList);
        });
    }

    @Override
    public int getOrder() {
        return Ordered.LOWEST_PRECEDENCE - 1;
    }
}
